@@ -1,6 +1,10 @@
 import warnings
+from multiprocessing.pool import Pool
 from typing import Union, Callable, List
 
+from tqdm import tqdm
+
+from mapfw.functime import time_fun
 from mapfw.problem import Problem
 from time import time
 import requests
@@ -62,18 +66,16 @@ class MapfwBenchmarker:
             self.load()
 
             while self.status["state"] == "RUNNING":
-                for problem in self.problems:
-                    if self.timeout:
-                        problem.start_time = time()
-                        try:
-                            solution = func_timeout(self.timeout / 1000, self.solver, args=(problem,))
-                        except FunctionTimedOut:
-                            solution = None
-                        problem.add_solution(solution)
-                    else:
-                        problem.start_time = time()
-                        solution = self.solver(problem)
-                        problem.add_solution(solution)
+                if self.timeout:
+                    solve_func = lambda problem: func_timeout(self.timeout / 1000, self.solver, args=(problem,))
+                else:
+                    solve_func = lambda problem: self.solver(problem)
+                time_func = lambda problem: time_fun(problem,solve_func)
+
+                with Pool() as p:
+                    p.imap(time_func,tqdm(self.problems))
+
+
 
     def submit(self):
         """"
